/*!
  \file
  \brief IvVj[

  \author Satofumi KAMIMURA

  $Id$

  \todo ڂ̐̓|bvAbvōs
  \todo KAnCXRAo^̋Ad_KA̍ڂzu
  \todo ̓[h̍XVs
*/

#include "OptionMenu.h"


struct OptionMenu::pImpl {
};


OptionMenu::OptionMenu(void) : pimpl(new pImpl) {
}


OptionMenu::~OptionMenu(void) {
}


void OptionMenu::run(void) {
  // !!!
}
